#!/usr/bin/env bash

# This script is the first phase of bootstrapping which operates against the AWS APIs before Access starts

set -e
set -x

function wait_for_service() {
  n=0
  until [ $n -ge ${2-10} ]
  do
    eval "$1" && break
    n=$((n+1))
    sleep 1
  done
}

DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
BULK_IMPORT_TEMPLATE_ROLES=${DIR}/bootstrap_roles_tmpl.json
FINAL_BULK_IMPORT_ROLES=/tmp/access_roles_bulk.json
BULK_IMPORT_TEMPLATE_GRANTS=${DIR}/service-connector-grant-template.json
FINAL_BULK_IMPORT_GRANTS=/tmp/access_grants_bulk.json

if [ -z "${ACCESS_DYNAMODB_TABLE_PREFIX}" ]; then
    ACCESS_ROLES_TABLE_NAME=access_roles
    ACCESS_GRANTS_TABLE_NAME=access_grants
else
    ACCESS_ROLES_TABLE_NAME=${ACCESS_DYNAMODB_TABLE_PREFIX}_access_roles
    ACCESS_GRANTS_TABLE_NAME=${ACCESS_DYNAMODB_TABLE_PREFIX}_access_grants
fi

if [ -n "${ACCESS_DYNAMODB_ENDPOINT}" ] ; then
    AWS_CLI_ENDPOINT_FLAG=--endpoint-url=${ACCESS_DYNAMODB_ENDPOINT}
fi

if [ -z "${AWS_DEFAULT_REGION}" ]; then
    echo "Discovering default region"
    export AWS_DEFAULT_REGION=$(curl -s http://169.254.169.254/latest/meta-data/placement/region)
fi

echo "Waiting for sts to return role assumed..."
wait_for_service "aws ${AWS_CLI_ENDPOINT_FLAG} sts get-caller-identity"

# The template json file needs to be wrapped by the role table name so it can be dynamically determined
echo "{\"${ACCESS_ROLES_TABLE_NAME}\":" > ${FINAL_BULK_IMPORT_ROLES}
cat ${BULK_IMPORT_TEMPLATE_ROLES} >> ${FINAL_BULK_IMPORT_ROLES}
echo "}" >> ${FINAL_BULK_IMPORT_ROLES}

echo "Importing bootstrap role data into table ${ACCESS_ROLES_TABLE_NAME}"
aws ${AWS_CLI_ENDPOINT_FLAG} dynamodb batch-write-item --request-items file:/${FINAL_BULK_IMPORT_ROLES}

if [[ -n "${MULTIENV_DB}" ]]; then
        ENVS=$(echo -n "$MULTIENV_DB" | jq -Mr 'keys_unsorted[]')
else
        ENVS=($ENV)
fi

for env in ${ENVS[@]}; do
	echo "Working on environment: ${env}"
	# Create grant for secops role manager
	ORGKEY=$(orgkey encode --env ${env} --id 1)
	echo "Using orgkey: ${ORGKEY}"
	
	echo "{\"${ACCESS_GRANTS_TABLE_NAME}\":[{\"PutRequest\":{\"Item\":" > ${FINAL_BULK_IMPORT_GRANTS}
	sed -e "s/{principal}/psc:cnn:${ORGKEY}:1/g" -e "s/{role}/psc:role::SECOPS_ROLE_MANAGER/g" -e "s/psc:org:R76KWHRN/psc:org:${ORGKEY}/g" < ${BULK_IMPORT_TEMPLATE_GRANTS} >> ${FINAL_BULK_IMPORT_GRANTS}
	echo "}}]}" >> ${FINAL_BULK_IMPORT_GRANTS}
	cat ${FINAL_BULK_IMPORT_GRANTS}
	echo "Importing bootstrap grant data into table ${ACCESS_GRANTS_TABLE_NAME}"
	aws ${AWS_CLI_ENDPOINT_FLAG} dynamodb batch-write-item --request-items file:/${FINAL_BULK_IMPORT_GRANTS}
done

if [ "${ENV}" == "local" ]; then
  # R AND D ROLE MANAGER SHOULD NOT BE MIGRATED IN PROD ENVS
  ORGKEY=$(orgkey encode --env ${ENV} --id 1)
  echo "Using orgkey: ${ORGKEY}"

  echo "{\"${ACCESS_GRANTS_TABLE_NAME}\":[{\"PutRequest\":{\"Item\":" > ${FINAL_BULK_IMPORT_GRANTS}
  sed -e "s/{principal}/psc:user:${ORGKEY}:1/g" -e "s/{role}/psc:role::R_AND_D_ROLE_MANAGER/g" < ${BULK_IMPORT_TEMPLATE_GRANTS} >> ${FINAL_BULK_IMPORT_GRANTS}
  echo "}}]}" >> ${FINAL_BULK_IMPORT_GRANTS}
  cat ${FINAL_BULK_IMPORT_GRANTS}
  echo "Importing bootstrap grant data into table ${ACCESS_GRANTS_TABLE_NAME}"
  aws ${AWS_CLI_ENDPOINT_FLAG} dynamodb batch-write-item --request-items file:/${FINAL_BULK_IMPORT_GRANTS}
fi
