#!/usr/bin/env bash

# This script is the second phase of bootstrapping which depends on Access' API

set -e
set -x

DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"

# Retry until platform-access is running.
if [ -z "${ACCESS_URL_HOST}" ]; then
    ACCESS_URL_HOST=platform-access
fi
if [ -z "${ACCESS_URL_PORT}" ]; then
    ACCESS_URL_PORT=8080
fi

HEALTH_URL=http://${ACCESS_URL_HOST}:${ACCESS_URL_PORT}/access/v1/healthCheck
echo "Waiting for ${HEALTH_URL} to return 200..."

ALT_ACCESS_URL_PORT=8902
ALT_HEALTH_URL=http://${ACCESS_URL_HOST}:${ALT_ACCESS_URL_PORT}/access/v1/healthCheck

until curl -m 20 --silent -f ${HEALTH_URL}; do
    echo "Will attempt alternative calls to ${ALT_HEALTH_URL} as well..."
    if curl -m 20 --silent -f ${ALT_HEALTH_URL}; then
    	HEALTH_URL=${ALT_HEALTH_URL}
        ACCESS_URL_PORT=${ALT_ACCESS_URL_PORT}
	break	
    fi
    sleep 2
done

ACCESS_URL=${CBC_HOST}

if [ "${CSP_ENABLED}" = "true" ]; then
    echo "CSP entities migration enabled"
    CSP_ARGS="--csp-enabled \
              --csp-url ${CSP_URL} \
              --csp-client-id ${CSP_AUTH_CLIENT_ID} \
              --csp-client-secret ${CSP_AUTH_CLIENT_SECRET} \
              --definition-id ${CSP_SERVICE_ID}"
fi

if [[ -n "${MULTIENV_DB}" ]]; then
	ENVS=$(echo -n "$MULTIENV_DB" | jq -Mr 'keys_unsorted[]')
else
	ENVS=($ENV)
fi

for env in ${ENVS[@]}; do
        echo "Working on environment: ${env}"
	ORGKEY=$(orgkey encode --env ${env} --id 1)
	echo "Using orgkey: ${ORGKEY}"
	
	python3 ${DIR}/migrate_v2_entities.py --all --url ${ACCESS_URL} \
	    --org-key ${ORGKEY} \
	    --request-context "{\"gateway_ip\":\"${ACCESS_URL}\",\"gateway_port\":\"${ACCESS_URL_PORT}\",\"gateway_public_url\":\"${ACCESS_URL}\",\"gateway_authenticated_port\":\"${ACCESS_URL_PORT}\",\"client_ip\":\"127.0.0.1\",\"correlation_id\":\"unknown\",\"origin_env\":\"${env}\"}" \
	    --user-context "{\"login_org\":{\"org_id\":1,\"user_name\":\"C\",\"org_key\":\"${ORGKEY}\",\"connector_id\":1,\"rbac_key\":\"SECOPS_ROLE_MANAGER\"},\"target_org\":{\"org_id\":1,\"user_name\":\"C\",\"org_key\":\"${ORGKEY}\",\"connector_id\":1,\"rbac_key\":\"SECOPS_ROLE_MANAGER\"}}" \
	    ${CSP_ARGS}
	    
	SALT=""
	if [ -n "$CONNECTOR_SALT" ]; then
	  SALT="--salt $CONNECTOR_SALT"
	fi
	
	python3 ${DIR}/add_service_connectors_grants.py --url ${ACCESS_URL} \
	    --org-key ${ORGKEY} \
	    --request-context "{\"gateway_ip\":\"${ACCESS_URL}\",\"gateway_port\":\"${ACCESS_URL_PORT}\",\"gateway_public_url\":\"${ACCESS_URL}\",\"gateway_authenticated_port\":\"${ACCESS_URL_PORT}\",\"client_ip\":\"127.0.0.1\",\"correlation_id\":\"unknown\",\"origin_env\":\"${env}\"}" \
	    --user-context "{\"login_org\":{\"org_id\":1,\"user_name\":\"C\",\"org_key\":\"${ORGKEY}\",\"connector_id\":1,\"rbac_key\":\"SECOPS_ROLE_MANAGER\"},\"target_org\":{\"org_id\":1,\"user_name\":\"C\",\"org_key\":\"${ORGKEY}\",\"connector_id\":1,\"rbac_key\":\"SECOPS_ROLE_MANAGER\"}}"
	    $SALT
done

python3 ${DIR}/finalize_connector_secrets.py $SALT
