import hashlib
import bcrypt

from psc_orgkey import encode_orgkey


def _encode(connector_value, salt, dklen=None):
    return hashlib.pbkdf2_hmac('sha256',
                               connector_value.encode('utf-8'),
                               salt.encode('utf-8'),
                               100000, dklen=dklen).hex()


# Actual length is dklen*2
def encode_connector_id(connector_name, salt, dklen=5):
    return _encode(connector_name, salt, dklen).upper()


# Actual length is dklen*2
def encode_api_key(connector_name, salt, dklen=16):
    return _encode(f"{connector_name}_SECRET", salt, dklen).upper()


# api_key: plain text connector secret. Will be stored in identity_key column
# connector_secret: encrypted connector secret. Will be stored in connector_secret column
def encode_connector_secret(api_key):
    return bcrypt.hashpw(api_key.encode('utf-8'), bcrypt.gensalt()).decode('utf-8')


def encode_org_key(env, org_id=1):
    return encode_orgkey(env=env, org_id=org_id)
