# Service Connectors

The scripts here are used to populate service connectors in ES. The connectors' definitions originally reside in the `psc.access` project, but are copied and packaged with this script in a Docker image. There is a separete file per connector.
The script will generate random connectorId and ApiKey for each connector following the pattern
used in cb-defense backend.

    ./create_backend_service_connectors.py -e <env> --es-url <ES_URL> --aws-region <AWS_REGION>

All of the following options can be skipped. The script will try to use the [ENV vars](#ENV-Vars), by default.

Options:

`-e`: Specify the environment (localdev, dev01, dev08).\
`--es-url`: The base URL for elasticsearch.\
`--aws-region`: The AWS region to connect.\
`--salt`: The salt used to encode connectorId and apiKey. If omitted, the org-key will be used as a salt.\


## Kubernetes and Mosaic2.0 environments

A docker image build from ../Dockerfile is used in Mosaic2.0 envs to populate the connectors in ES and
in addition to create a Kubernetes Secret object per connector.
The secret name is the file name which defines the respective connector, lower cased and '_' replaced with '-'.
The secret itself has two keys:
* connector-id : connectorId value
* api-key : ApiKey value

### ENV Vars:

`ES_PROTOCOL`:  Default is `http`\
`ES_HOST`: Default is `elasticsearch`\
`ES_PORT`: Default is `9200`\
`ES_URL`: Default is `${ES_PROTOCOL}://${ES_HOST}:${ES_PORT}`\
`AWS_REGION`: Default is us-west-2\
`ENV`: Specify the environment (localdev, dev01, dev08)\
`NS_APPS`: k8s apps namespace to use to create Secrets per connector.\
`NS_INFRA`: k8s infra namespace to use to create Secrets per connector.\
`CONNECTOR_SALT`: The salt used to encode connectorId and apiKey. If used, it should be same\
as the one passed to `bootstrap_live.sh` to correctly import grants for connectors\

Example using secret in a service:

    - name: CONNECTOR_ID
      valueFrom:
        secretKeyRef:
            name: access-service-connector
            key: connector-id
    - name: API_KEY
      valueFrom:
        secretKeyRef:
            name: access-service-connector
            key: api-key
